@@ -15,7 +15,7 @@ def parse_args():
     )
     p.add("-c", "--config", is_config_file=True, help="config file path")
     p.add_argument("--log-level", "-L", default="DEBUG", env_var="LOG_LEVEL")
-    p.add_argument("--log-file", action="store_true", env_var="LOG_FILE")
+    p.add_argument("--log-file", type=str, default=True, env_var="LOG_FILE")
 
     p.add_argument(
         "--datastore-path",
